@@ -21,7 +21,10 @@ use core::{
     pin::Pin,
     slice,
 };
-use std::collections::{HashMap, HashSet};
+use std::{
+    collections::{HashMap, HashSet},
+    hash::BuildHasher,
+};
 
 #[cfg_attr(feature = "strict", repr(C))]
 struct Entry<K, V> {
@@ -248,7 +251,7 @@ impl<K: Hash + Eq, V> ArchivedHashMap<K, V> {
         }
     }
 
-    fn serialize_from_iter<
+    pub fn serialize_from_iter<
         'a,
         KU: 'a + Serialize<S, Archived = K> + Hash + Eq,
         VU: 'a + Serialize<S, Archived = V>,
@@ -606,7 +609,7 @@ impl ArchivedHashMapResolver {
     }
 }
 
-impl<K: Archive + Hash + Eq, V: Archive> Archive for HashMap<K, V>
+impl<K: Archive + Hash + Eq, V: Archive, S> Archive for HashMap<K, V, S>
 where
     K::Archived: Hash + Eq,
 {
@@ -619,8 +622,8 @@ where
     }
 }
 
-impl<K: Serialize<S> + Hash + Eq, V: Serialize<S>, S: Serializer + ?Sized> Serialize<S>
-    for HashMap<K, V>
+impl<K: Serialize<S> + Hash + Eq, V: Serialize<S>, S: Serializer + ?Sized, RandomState> Serialize<S>
+    for HashMap<K, V, RandomState>
 where
     K::Archived: Hash + Eq,
 {
@@ -630,15 +633,15 @@ where
     }
 }
 
-impl<K: Archive + Hash + Eq, V: Archive, D: Fallible + ?Sized> Deserialize<HashMap<K, V>, D>
-    for Archived<HashMap<K, V>>
+impl<K: Archive + Hash + Eq, V: Archive, D: Fallible + ?Sized, S: Default + BuildHasher>
+    Deserialize<HashMap<K, V, S>, D> for Archived<HashMap<K, V>>
 where
     K::Archived: Deserialize<K, D> + Hash + Eq,
     V::Archived: Deserialize<V, D>,
 {
     #[inline]
-    fn deserialize(&self, deserializer: &mut D) -> Result<HashMap<K, V>, D::Error> {
-        let mut result = HashMap::with_capacity(self.len());
+    fn deserialize(&self, deserializer: &mut D) -> Result<HashMap<K, V, S>, D::Error> {
+        let mut result = HashMap::with_capacity_and_hasher(self.len(), S::default());
         for (k, v) in self.iter() {
             result.insert(k.deserialize(deserializer)?, v.deserialize(deserializer)?);
         }
@@ -660,11 +663,11 @@ impl<K: Hash + Eq, V: PartialEq> PartialEq for ArchivedHashMap<K, V> {
 
 impl<K: Hash + Eq, V: Eq> Eq for ArchivedHashMap<K, V> {}
 
-impl<K: Hash + Eq + Borrow<AK>, V, AK: Hash + Eq, AV: PartialEq<V>> PartialEq<HashMap<K, V>>
-    for ArchivedHashMap<AK, AV>
+impl<K: Hash + Eq + Borrow<AK>, V, AK: Hash + Eq, AV: PartialEq<V>, S: BuildHasher>
+    PartialEq<HashMap<K, V, S>> for ArchivedHashMap<AK, AV>
 {
     #[inline]
-    fn eq(&self, other: &HashMap<K, V>) -> bool {
+    fn eq(&self, other: &HashMap<K, V, S>) -> bool {
         if self.len() != other.len() {
             false
         } else {
@@ -695,6 +698,7 @@ impl<K: Eq + Hash + Borrow<Q>, Q: Eq + Hash + ?Sized, V> Index<&'_ Q> for Archiv
 /// An archived `HashSet`. This is a wrapper around a hash map with the same key and a value of
 /// `()`.
 #[derive(Eq, PartialEq)]
+#[cfg_attr(feature = "validation", derive(bytecheck::CheckBytes))]
 #[repr(transparent)]
 pub struct ArchivedHashSet<K: Hash + Eq>(ArchivedHashMap<K, ()>);
 
